Generated Github Ex operations for checks.
Summary
Functions
Create a check run
Create a check suite
Get a check run
Get a check suite
List check run annotations
List check runs for a Git reference
List check runs in a check suite
List check suites for a Git reference
Rerequest a check run
Rerequest a check suite
Update repository preferences for check suites
Update a check run
Functions
Create a check run
Creates a new check run for a specific commit in a repository.
To create a check run, you must use a GitHub App. OAuth apps and authenticated users are not able to create a check suite.
In a check suite, GitHub limits the number of check runs with the same name to 1000. Once these check runs exceed 1000, GitHub will start to automatically delete older check runs.
[!NOTE] The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty
pull_requestsarray.
Create a check suite
Creates a check suite manually. By default, check suites are automatically created when you create a check run. You only need to use this endpoint for manually creating check suites when you've disabled automatic creation using "Update repository preferences for check suites".
[!NOTE] The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty
pull_requestsarray and anullvalue forhead_branch.
OAuth apps and personal access tokens (classic) cannot use this endpoint.
Get a check run
Gets a single check run using its id.
[!NOTE] The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty
pull_requestsarray.
OAuth app tokens and personal access tokens (classic) need the repo scope to use this endpoint on a private repository.
Get a check suite
Gets a single check suite using its id.
[!NOTE] The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty
pull_requestsarray and anullvalue forhead_branch.
OAuth app tokens and personal access tokens (classic) need the repo scope to use this endpoint on a private repository.
List check run annotations
Lists annotations for a check run using the annotation id.
OAuth app tokens and personal access tokens (classic) need the repo scope to use this endpoint on a private repository.
List check runs for a Git reference
Lists check runs for a commit ref. The ref can be a SHA, branch name, or a tag name.
[!NOTE] The endpoints to manage checks only look for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty
pull_requestsarray.
If there are more than 1000 check suites on a single git reference, this endpoint will limit check runs to the 1000 most recent check suites. To iterate over all possible check runs, use the List check suites for a Git reference endpoint and provide the check_suite_id parameter to the List check runs in a check suite endpoint.
OAuth app tokens and personal access tokens (classic) need the repo scope to use this endpoint on a private repository.
List check runs in a check suite
Lists check runs for a check suite using its id.
[!NOTE] The endpoints to manage checks only look for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty
pull_requestsarray.
OAuth app tokens and personal access tokens (classic) need the repo scope to use this endpoint on a private repository.
List check suites for a Git reference
Lists check suites for a commit ref. The ref can be a SHA, branch name, or a tag name.
[!NOTE] The endpoints to manage checks only look for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty
pull_requestsarray and anullvalue forhead_branch.
OAuth app tokens and personal access tokens (classic) need the repo scope to use this endpoint on a private repository.
Rerequest a check run
Triggers GitHub to rerequest an existing check run, without pushing new code to a repository. This endpoint will trigger the check_run webhook event with the action rerequested. When a check run is rerequested, the status of the check suite it belongs to is reset to queued and the conclusion is cleared. The check run itself is not updated. GitHub apps recieving the check_run webhook with the rerequested action should then decide if the check run should be reset or updated and call the update check_run endpoint to update the check_run if desired.
For more information about how to re-run GitHub Actions jobs, see "Re-run a job from a workflow run".
Rerequest a check suite
Triggers GitHub to rerequest an existing check suite, without pushing new code to a repository. This endpoint will trigger the check_suite webhook event with the action rerequested. When a check suite is rerequested, its status is reset to queued and the conclusion is cleared.
Update repository preferences for check suites
Changes the default automatic flow when creating check suites. By default, a check suite is automatically created each time code is pushed to a repository. When you disable the automatic creation of check suites, you can manually Create a check suite. You must have admin permissions in the repository to set preferences for check suites.
@spec stream_list_annotations(term(), map(), keyword()) :: Enumerable.t()
@spec stream_list_for_ref(term(), map(), keyword()) :: Enumerable.t()
@spec stream_list_for_suite(term(), map(), keyword()) :: Enumerable.t()
@spec stream_list_suites_for_ref(term(), map(), keyword()) :: Enumerable.t()
Update a check run
Updates a check run for a specific commit in a repository.
[!NOTE] The endpoints to manage checks only look for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty
pull_requestsarray.
OAuth apps and personal access tokens (classic) cannot use this endpoint.